# coloreg

Style, sheet, theme - simple coloring for python standard `logging` module

*Currently works only for '{'-style formatting*

## Install

Install directly with `pip`

```bash
pip install coloreg
```

